@@ -24,7 +24,7 @@
 #include "widgets_export.h"
 #include <KFileItem>
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 
 namespace Baloo {
@@ -38,8 +38,8 @@ class BALOO_WIDGETS_EXPORT FileMetaDataConfigWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit FileMetaDataConfigWidget(QWidget* parent = 0);
-    virtual ~FileMetaDataConfigWidget();
+    explicit FileMetaDataConfigWidget(QWidget* parent = nullptr);
+    ~FileMetaDataConfigWidget() override;
 
     /**
      * Sets the items, for which the visibility of the meta data should
@@ -59,10 +59,10 @@ public:
     void save();
 
     /** @see QWidget::sizeHint() */
-    virtual QSize sizeHint() const;
+    QSize sizeHint() const override;
 
 protected:
-    virtual bool event(QEvent* event);
+    bool event(QEvent* event) override;
 
 private:
     class Private;
