@@ -152,6 +152,7 @@ void FileMetaDataProvider::insertSingleFileBasicData()
     if (m_fileItems.count() == 1) {
       const KFileItem& item = m_fileItems.first();
 
+      KFormat format;
       if (item.isDir()) {
           bool isSizeUnknown = !item.isLocalFile();
           if (!isSizeUnknown) {
@@ -171,28 +172,34 @@ void FileMetaDataProvider::insertSingleFileBasicData()
               }
           }
           else if (item.entry().contains(KIO::UDSEntry::UDS_SIZE)) {
-              isSizeUnknown = false;
-              KFormat format;
               m_data.insert(QStringLiteral("kfileitem#size"), format.formatByteSize(item.size()));
           }
-          if (isSizeUnknown) {
-              m_data.insert(QStringLiteral("kfileitem#size"), i18nc("unknown file size", "Unknown"));
+          if (item.entry().contains(KIO::UDSEntry::UDS_RECURSIVE_SIZE)) {
+              m_data.insert(QStringLiteral("kfileitem#totalSize"), format.formatByteSize(item.recursiveSize()));
           }
       } else {
-          KFormat format;
-          m_data.insert(QStringLiteral("kfileitem#size"), format.formatByteSize(item.size()));
+          if (item.entry().contains(KIO::UDSEntry::UDS_SIZE)) {
+              m_data.insert(QStringLiteral("kfileitem#size"), format.formatByteSize(item.size()));
+          }
       }
 
       m_data.insert(QStringLiteral("kfileitem#type"), item.mimeComment());
       if (item.isLink()) {
           m_data.insert(QStringLiteral("kfileitem#linkDest"), item.linkDest());
       }
-      m_data.insert(QStringLiteral("kfileitem#modified"), item.time(KFileItem::ModificationTime));
+      QDateTime modificationTime = item.time(KFileItem::ModificationTime);
+      if (modificationTime.isValid()) {
+          m_data.insert(QStringLiteral("kfileitem#modified"), modificationTime);
+      }
       QDateTime creationTime = item.time(KFileItem::CreationTime);
       if (creationTime.isValid()) {
           m_data.insert(QStringLiteral("kfileitem#created"), creationTime);
       }
-      m_data.insert(QStringLiteral("kfileitem#accessed"), item.time(KFileItem::AccessTime));
+      QDateTime accessTime = item.time(KFileItem::AccessTime);
+      if (accessTime.isValid()) {
+          m_data.insert(QStringLiteral("kfileitem#accessed"), accessTime);
+      }
+
       m_data.insert(QStringLiteral("kfileitem#owner"), item.user());
       m_data.insert(QStringLiteral("kfileitem#group"), item.group());
       m_data.insert(QStringLiteral("kfileitem#permissions"), item.permissionsString());
