@@ -27,6 +27,7 @@
 #include <QStringList>
 
 class KJob;
+class QLabel;
 class QUrl;
 class KCommentWidget;
 class KRatingWidget;
@@ -43,10 +44,9 @@ namespace Baloo {
         explicit WidgetFactory(QObject* parent = nullptr);
         ~WidgetFactory() override;
 
-        void setItems(const QStringList& items);
+        void setItems(const KFileItemList& items);
 
         void setReadOnly(bool value);
-        void setNoLinks(bool value);
 
         void setDateFormat(const DateFormats format);
         DateFormats dateFormat() const;
@@ -70,16 +70,15 @@ namespace Baloo {
         QWidget* createRatingWidget(int rating, QWidget* parent);
         QWidget* createTagWidget(const QStringList& tags, QWidget* parent);
         QWidget* createCommentWidget(const QString& comment, QWidget* parent);
-        QWidget* createValueWidget(const QString& value, QWidget* parent);
+        QLabel* createValueWidget(QWidget* parent);
 
         TagWidget* m_tagWidget;
         KRatingWidget* m_ratingWidget;
         KCommentWidget* m_commentWidget;
 
-        QStringList m_items;
+        KFileItemList m_items;
         QStringList m_prevTags;
         bool m_readOnly;
-        bool m_noLinks;
         QLocale::FormatType m_dateFormat;
     };
 }
