@@ -1,5 +1,5 @@
 /*
-   This file is part of the Nepomuk KDE project.
+   This file is part of the Baloo KDE project.
    Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
 #ifndef TAGWIDGETTEST_H
 #define TAGWIDGETTEST_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 #include "tagwidget.h"
 
 class TagWidgetTest : public QWidget
@@ -30,7 +30,7 @@ class TagWidgetTest : public QWidget
 
 public:
     TagWidgetTest();
-    ~TagWidgetTest();
+    ~TagWidgetTest() override;
 
 public Q_SLOTS:
     void slotTagClicked(const QString&);
